=======
Credits
=======

Development Lead
----------------

* Alexis Jeandet <alexis.jeandet@member.fsf.org>

Contributors
------------

AMDA Webservice
^^^^^^^^^^^^^^^

* Alexandre Schulz <alexandre.schulz@irap.omp.eu>
* Benjamin Renard <benjamin.renard@irap.omp.eu>
